#ifndef TRASH_PLUGIN_H
#define TRASH_PLUGIN_H

void trash_plugin_init(void);
void trash_plugin_deinit(void);

#endif
